@@ -112,7 +112,7 @@ for(var in c('GFE', 'AI_mod', 'DBE')){
 
 #### Plot - Density Diagram ####
 
-for(var in c('GFE', 'AI', 'DBE')){
+for(var in c('GFE', 'AI_mod', 'DBE')){
   var_s = syms(var)
   density_plot <- ggplot(df_longer,
                          aes(x = (!!! var_s),
@@ -130,7 +130,7 @@ for(var in c('GFE', 'AI', 'DBE')){
 }
 #### Plot - Violin ####
 
-for(var in c('GFE', 'AI', 'DBE')){
+for(var in c('GFE', 'AI_mod', 'DBE')){
   
   var_s = syms(var)
   formula <- formula(paste0(var, ' ~ %group1%'))
@@ -163,7 +163,7 @@ for(var in c('GFE', 'AI', 'DBE')){
 
 # Magnitude-weighted values
 
-for(var in c('GFE', 'AI', 'DBE')){
+for(var in c('GFE', 'AI_mod', 'DBE')){
   
   var_s = syms(var)
   newnames <- paste0(var, c('_weighted', '_magniture_average'))
@@ -210,6 +210,9 @@ for(var in c('GFE', 'AI', 'DBE')){
 
 #### Plot - Class comp bar####
 
+class_colors <- brewer.pal(9, name = 'Set3')
+names(class_colors) <- c(classification$Class, 'Other')
+
 class_bar <- class_comp %>% 
   group_by(%group1%, %group2%, Class)  %>% 
   summarise(Count = mean(Count), .groups = 'drop') %>% 
@@ -218,7 +221,7 @@ class_bar <- class_comp %>%
              fill = Class)) +
   geom_col() +
   theme_bw() +
-  scale_fill_brewer(palette = 'Set3') +
+  scale_fill_manual(values = class_colors) +
   labs(title = 'Class Composition') +
   theme(plot.title = element_text(face = 'bold', hjust = 0.5)) +
   facet_grid(cols = vars(%group2%))
@@ -427,7 +430,7 @@ for(i in 1:ncol(comb_g1)){
                fill = Class)) +
     geom_col() +
     theme_bw() +
-    scale_fill_brewer(palette = 'Set3') +
+    scale_fill_manual(values = class_colors) +
     labs(title = 'Class Composition') +
     theme(plot.title = element_text(face = 'bold', hjust = 0.5),
           axis.title = element_blank(),
@@ -590,7 +593,7 @@ dir.create(comparison_dir)
                  fill = Class)) +
       geom_col() +
       theme_bw() +
-      scale_fill_brewer(palette = 'Set3') +
+      scale_fill_manual(values = class_colors) +
       labs(title = 'Class Composition') +
       theme(plot.title = element_text(face = 'bold', hjust = 0.5),
             axis.title = element_blank(),
